tests.test_display module — justbases 0.07 documentation

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »

# tests.test_display module

Test for utility functions.

class `tests.test_display.` `TestDigits`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Test Digits methods.

  `testExceptions`()

    Test exceptions.

class `tests.test_display.` `TestNumber`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Test Number.

  `testXform`()

    Test xform.

class `tests.test_display.` `TestString`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Test display of Radix given display configuration.

  `testFormat`()

    Verify that a xformed string with a repeating part shows that part.

class `tests.test_display.` `TestStrip`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Test Strip.

  `testXform`()

    Confirm that option strip strips more than other options.

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »